.. crabpy_pyramid documentation master file, created by
   sphinx-quickstart on Wed Feb 19 09:56:43 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to crabpy_pyramid's documentation!
==========================================

.. toctree::
   :maxdepth: 2

   setup
   services
   api
   changes


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

